==> openshift-model-monitoring-5.11.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/Sigv4FluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class Sigv4FluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<A>{
  public Sigv4FluentImpl() {
  }
  public Sigv4FluentImpl(io.fabric8.openshift.api.model.monitoring.v1.Sigv4 instance) {
    this.withAccessKey(instance.getAccessKey()); 
    this.withProfile(instance.getProfile()); 
    this.withRegion(instance.getRegion()); 
    this.withRoleArn(instance.getRoleArn()); 
    this.withSecretKey(instance.getSecretKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.SecretKeySelector accessKey;
  private java.lang.String profile;
  private java.lang.String region;
  private java.lang.String roleArn;
  private io.fabric8.kubernetes.api.model.SecretKeySelector secretKey;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public io.fabric8.kubernetes.api.model.SecretKeySelector getAccessKey() {
    return this.accessKey;
  }
  public A withAccessKey(io.fabric8.kubernetes.api.model.SecretKeySelector accessKey) {
    this.accessKey=accessKey; return (A) this;
  }
  public java.lang.Boolean hasAccessKey() {
    return this.accessKey != null;
  }
  public A withNewAccessKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withAccessKey(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getProfile() {
    return this.profile;
  }
  public A withProfile(java.lang.String profile) {
    this.profile=profile; return (A) this;
  }
  public java.lang.Boolean hasProfile() {
    return this.profile != null;
  }
  
  /**
   * Method is deprecated. use withProfile instead.
   */
  @java.lang.Deprecated
  public A withNewProfile(java.lang.String arg0) {
    return (A)withProfile(new String(arg0));
  }
  public java.lang.String getRegion() {
    return this.region;
  }
  public A withRegion(java.lang.String region) {
    this.region=region; return (A) this;
  }
  public java.lang.Boolean hasRegion() {
    return this.region != null;
  }
  
  /**
   * Method is deprecated. use withRegion instead.
   */
  @java.lang.Deprecated
  public A withNewRegion(java.lang.String arg0) {
    return (A)withRegion(new String(arg0));
  }
  public java.lang.String getRoleArn() {
    return this.roleArn;
  }
  public A withRoleArn(java.lang.String roleArn) {
    this.roleArn=roleArn; return (A) this;
  }
  public java.lang.Boolean hasRoleArn() {
    return this.roleArn != null;
  }
  
  /**
   * Method is deprecated. use withRoleArn instead.
   */
  @java.lang.Deprecated
  public A withNewRoleArn(java.lang.String arg0) {
    return (A)withRoleArn(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getSecretKey() {
    return this.secretKey;
  }
  public A withSecretKey(io.fabric8.kubernetes.api.model.SecretKeySelector secretKey) {
    this.secretKey=secretKey; return (A) this;
  }
  public java.lang.Boolean hasSecretKey() {
    return this.secretKey != null;
  }
  public A withNewSecretKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withSecretKey(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    Sigv4FluentImpl that = (Sigv4FluentImpl) o;
    if (accessKey != null ? !accessKey.equals(that.accessKey) :that.accessKey != null) return false;
    if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
    if (region != null ? !region.equals(that.region) :that.region != null) return false;
    if (roleArn != null ? !roleArn.equals(that.roleArn) :that.roleArn != null) return false;
    if (secretKey != null ? !secretKey.equals(that.secretKey) :that.secretKey != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accessKey,  profile,  region,  roleArn,  secretKey,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/Sigv4FluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.SecretKeySelector;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class Sigv4FluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<A>{
  public Sigv4FluentImpl() {
  }
  public Sigv4FluentImpl(io.fabric8.openshift.api.model.monitoring.v1.Sigv4 instance) {
    this.withAccessKey(instance.getAccessKey()); 
    this.withProfile(instance.getProfile()); 
    this.withRegion(instance.getRegion()); 
    this.withRoleArn(instance.getRoleArn()); 
    this.withSecretKey(instance.getSecretKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.SecretKeySelector accessKey;
  private java.lang.String profile;
  private java.lang.String region;
  private java.lang.String roleArn;
  private io.fabric8.kubernetes.api.model.SecretKeySelector secretKey;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public io.fabric8.kubernetes.api.model.SecretKeySelector getAccessKey() {
    return this.accessKey;
  }
  public A withAccessKey(io.fabric8.kubernetes.api.model.SecretKeySelector accessKey) {
    this.accessKey=accessKey; return (A) this;
  }
  public java.lang.Boolean hasAccessKey() {
    return this.accessKey != null;
  }
  public A withNewAccessKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withAccessKey(new SecretKeySelector(key, name, optional));
  }
  public java.lang.String getProfile() {
    return this.profile;
  }
  public A withProfile(java.lang.String profile) {
    this.profile=profile; return (A) this;
  }
  public java.lang.Boolean hasProfile() {
    return this.profile != null;
  }
  
  /**
   * Method is deprecated. use withProfile instead.
   */
  @java.lang.Deprecated
  public A withNewProfile(java.lang.String arg0) {
    return (A)withProfile(new String(arg0));
  }
  public java.lang.String getRegion() {
    return this.region;
  }
  public A withRegion(java.lang.String region) {
    this.region=region; return (A) this;
  }
  public java.lang.Boolean hasRegion() {
    return this.region != null;
  }
  
  /**
   * Method is deprecated. use withRegion instead.
   */
  @java.lang.Deprecated
  public A withNewRegion(java.lang.String arg0) {
    return (A)withRegion(new String(arg0));
  }
  public java.lang.String getRoleArn() {
    return this.roleArn;
  }
  public A withRoleArn(java.lang.String roleArn) {
    this.roleArn=roleArn; return (A) this;
  }
  public java.lang.Boolean hasRoleArn() {
    return this.roleArn != null;
  }
  
  /**
   * Method is deprecated. use withRoleArn instead.
   */
  @java.lang.Deprecated
  public A withNewRoleArn(java.lang.String arg0) {
    return (A)withRoleArn(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.SecretKeySelector getSecretKey() {
    return this.secretKey;
  }
  public A withSecretKey(io.fabric8.kubernetes.api.model.SecretKeySelector secretKey) {
    this.secretKey=secretKey; return (A) this;
  }
  public java.lang.Boolean hasSecretKey() {
    return this.secretKey != null;
  }
  public A withNewSecretKey(java.lang.String key,java.lang.String name,java.lang.Boolean optional) {
    return (A)withSecretKey(new SecretKeySelector(key, name, optional));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    Sigv4FluentImpl that = (Sigv4FluentImpl) o;
    if (accessKey != null ? !accessKey.equals(that.accessKey) :that.accessKey != null) return false;
    if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
    if (region != null ? !region.equals(that.region) :that.region != null) return false;
    if (roleArn != null ? !roleArn.equals(that.roleArn) :that.roleArn != null) return false;
    if (secretKey != null ? !secretKey.equals(that.secretKey) :that.secretKey != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accessKey,  profile,  region,  roleArn,  secretKey,  additionalProperties,  super.hashCode());
  }
  
}
